[gvfs] Do not ignore CD drives with blank media



commit 127dc4251ea02365968996b6508c850943281422
Author: Martin Pitt <martin pitt ubuntu com>
Date:   Wed Apr 14 10:42:50 2010 +0200

    Do not ignore CD drives with blank media
    
    Extend the special casing of CD drives in should_drive_be_ignored() to also
    cover blank media. Otherwise we lose the drive for the blank media volume, and
    with it the possibility to eject it.
    
    Bug: https://bugzilla.gnome.org/show_bug.cgi?id=598554
    Bug-Ubuntu: https://launchpad.net/bugs/425104

 monitor/gdu/ggduvolumemonitor.c |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)
---
diff --git a/monitor/gdu/ggduvolumemonitor.c b/monitor/gdu/ggduvolumemonitor.c
index 4381d8b..446acfc 100644
--- a/monitor/gdu/ggduvolumemonitor.c
+++ b/monitor/gdu/ggduvolumemonitor.c
@@ -947,10 +947,11 @@ should_drive_be_ignored (GduPool *pool, GduDrive *d, GList *fstab_mount_points)
             ignored = TRUE;
         }
 
       /* special case for audio discs: don't ignore the drive since we'll create
        * a cdda:// mount for the drive
        */
-      if (gdu_device_is_optical_disc (device) && gdu_device_optical_disc_get_num_audio_tracks (device) > 0)
+      if (gdu_device_is_optical_disc (device) && (gdu_device_optical_disc_get_num_audio_tracks (device) > 0 ||
+                                                  gdu_device_optical_disc_get_is_blank (device)))
         {
           ignored = FALSE;
         }
@@ -947,10 +947,11 @@ should_drive_be_ignored (GduPool *pool, GduDrive *d, GList *fstab_mount_points)
         }
 
-      /* special case for audio discs: don't ignore the drive since we'll create
-       * a cdda:// mount for the drive
+      /* special case for audio and blank discs: don't ignore the drive since we'll create
+       * a cdda:// or burn:// mount for the drive
        */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]